import { VideoPlaylistPrivacy, VideoPlaylistType } from '@peertube/peertube-models';
import { logger } from '../helpers/logger.js';
import { VideoPlaylistModel } from '../models/video/video-playlist.js';
import { sendUpdateVideoPlaylist } from './activitypub/send/send-update.js';
import { getLocalVideoPlaylistActivityPubUrl } from './activitypub/url.js';
import { VideoMiniaturePermanentFileCache } from './files-cache/video-miniature-permanent-file-cache.js';
import { updateLocalPlaylistMiniatureFromExisting } from './thumbnail.js';
export async function createWatchLaterPlaylist(account, t) {
    const videoPlaylist = new VideoPlaylistModel({
        name: 'Watch later',
        privacy: VideoPlaylistPrivacy.PRIVATE,
        type: VideoPlaylistType.WATCH_LATER,
        ownerAccountId: account.id
    });
    videoPlaylist.url = getLocalVideoPlaylistActivityPubUrl(videoPlaylist);
    await videoPlaylist.save({ transaction: t });
    videoPlaylist.OwnerAccount = account;
    return videoPlaylist;
}
export async function generateThumbnailForPlaylist(videoPlaylist, video) {
    logger.info('Generating default thumbnail to playlist %s.', videoPlaylist.url);
    const videoMiniature = video.getMiniature();
    if (!videoMiniature) {
        logger.info('Cannot generate thumbnail for playlist %s because video %s does not have any.', videoPlaylist.url, video.url);
        return;
    }
    const videoMiniaturePermanentFileCache = new VideoMiniaturePermanentFileCache();
    const inputPath = videoMiniature.isOwned()
        ? videoMiniature.getPath()
        : await videoMiniaturePermanentFileCache.downloadRemoteFile(videoMiniature);
    const thumbnailModel = await updateLocalPlaylistMiniatureFromExisting({
        inputPath,
        playlist: videoPlaylist,
        automaticallyGenerated: true,
        keepOriginal: true
    });
    thumbnailModel.videoPlaylistId = videoPlaylist.id;
    videoPlaylist.Thumbnail = await thumbnailModel.save();
}
export async function reorderPlaylistOrElementsPosition(options) {
    const { model, start, insertAfter, reorderLength, instance, transaction } = options;
    const newPosition = insertAfter + 1;
    await model.increasePositionOf({
        videoChannelId: instance.id,
        videoPlaylistId: instance.id,
        fromPosition: newPosition,
        by: reorderLength,
        transaction
    });
    let oldPosition = start;
    if (start >= newPosition)
        oldPosition += reorderLength;
    const endOldPosition = oldPosition + reorderLength - 1;
    await model.reassignPositionOf({
        videoPlaylistId: instance.id,
        videoChannelId: instance.id,
        firstPosition: oldPosition,
        endPosition: endOldPosition,
        newPosition,
        transaction
    });
    await model.increasePositionOf({
        videoPlaylistId: instance.id,
        videoChannelId: instance.id,
        fromPosition: oldPosition,
        by: -reorderLength,
        transaction
    });
}
export async function sendPlaylistPositionUpdateOfChannel(channelId, transaction) {
    const playlists = await VideoPlaylistModel.listPlaylistOfChannel(channelId, transaction);
    for (const playlist of playlists) {
        await sendUpdateVideoPlaylist(playlist, transaction);
    }
}
//# sourceMappingURL=video-playlist.js.map